% Options.lhs
%
% This file is part of CalcCheck
%
% Copyright (c) 2011--2013  Wolfram Kahl
% All rights reserved
%
\section{Command-line |Options|}

\begin{code}
module Options where

import Version

import System.Environment (getArgs)
\end{code}


\begin{code}
data CalcCheckOpts = CalcCheckOpts
  { opt_quiet      :: Bool
  , opt_noVersion  :: Bool
  , opt_beamer     :: Bool
  }

defaultOptions :: CalcCheckOpts
defaultOptions = CalcCheckOpts
  { opt_quiet      = False
  , opt_noVersion  = False
  , opt_beamer     = False
  }
\end{code}

\begin{code}
getOpts :: CalcCheckOpts -> [String] -> (CalcCheckOpts, [String])
getOpts = h id
  where
    h f cco ("-q"           : ss)  = h f (cco {opt_quiet = True}) ss
    h f cco ("--noVersion"  : ss)  = h f (cco {opt_noVersion = True}) ss
    h f cco ("--beamer"     : ss)  = h f (cco {opt_beamer = True}) ss
    h f cco (s              : ss)  = h (f . (s :)) cco ss
    h f cco []                     = (cco, f [])
\end{code}

\begin{code}
getOptsAndArgs :: IO (CalcCheckOpts, [String])
getOptsAndArgs = fmap (getOpts defaultOptions) getArgs
\end{code}

\begin{code}
programId :: CalcCheckOpts -> String
programId cco = if opt_noVersion cco then programName else version

programIdPrefix, programIdPrefixHTML :: CalcCheckOpts -> ShowS
programIdPrefix     cco = (" ─ "       ++) . (programId cco ++) . (": " ++)
programIdPrefixHTML cco = (" &mdash; " ++) . (programId cco ++) . (": " ++)
\end{code}




%{{{ EMACS lv
% Local Variables:
% folded-file: t
% fold-internal-margins: 0
% eval: (fold-set-marks "%{{{ " "%}}}")
% eval: (fold-whole-buffer)
% end:
%}}}
